@@ -66,13 +66,21 @@ class PgDatabase:
 
     def __init__(self, **kwargs):
         self._settings = kwargs.get('settings')
+        if not isinstance(self._settings, dict):
+            self._settings = dict()
         self._auto_disconnect = kwargs.get('auto_disconnect', self._auto_disconnect)
         self._connection = kwargs.get('connection')
         if self._connection is not None:
             self._auto_disconnect = False
         if kwargs.get('schema') is not None:
-            if not isinstance(self._settings, dict):
-                self._settings['schema'] = kwargs.get('schema')
+            self._settings['schema'] = kwargs.get('schema')
+
+    @staticmethod
+    def build_dict_from_row(cursor, row):
+        x = {}
+        for key, col in enumerate(cursor.description):
+            x[col[0]] = row[key]
+        return x
 
     def get_attr(self, attr_name):
         if not isinstance(self._settings, dict):
@@ -146,12 +154,6 @@ class PgDatabase:
         return _dict
 
     def _execute(self, sql_string, sql_params=None, get_result=True):
-        @staticmethod
-        def build_dict(cursor, row):
-            x = {}
-            for key, col in enumerate(cursor.description):
-                x[col[0]] = row[key]
-            return x
 
         err_str = f'Error in {self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
         if not self.connect_to_db():
@@ -165,7 +167,7 @@ class PgDatabase:
             if get_result:
                 result = cursor.fetchall() or []
                 if result and isinstance(result[0], tuple):
-                    self._result = list(map(lambda row: build_dict(cursor, row), result))
+                    self._result = list(map(lambda row: self.build_dict_from_row(cursor, row), result))
                 else:
                     self._result = result
             return True
@@ -179,18 +181,9 @@ class PgDatabase:
             if cursor is not None:
                 cursor.close()
 
-    def is_in_transaction(self):
-        if self._connection is None:
-            return False
-        if self._connection.status == psycopg2.extensions.STATUS_READY \
-                and self._connection.isolation_level == psycopg2.extensions.ISOLATION_LEVEL_READ_COMMITTED:
-            return True
-        return self._connection.status == psycopg2.extensions.STATUS_IN_TRANSACTION
-
     def begin(self):
         if not self.connect_to_db():
             return False
-        self._connection.set_isolation_level(psycopg2.extensions.ISOLATION_LEVEL_READ_COMMITTED)
         return True
 
     def do(self, sql_string, sql_params=None):
@@ -203,7 +196,6 @@ class PgDatabase:
     def commit(self):
         if self._connection is not None:
             self._connection.commit()
-            self._connection.set_isolation_level(psycopg2.extensions.ISOLATION_LEVEL_AUTOCOMMIT)
 
     def rollback(self):
         if self._connection is not None:
@@ -337,7 +329,9 @@ class PgDatabase:
                 sql_params.append(psycopg2.extras.Json(v))
             else:
                 sql_params.append(v)
-        return self._execute_sql(sql_string=result_sql, sql_params=sql_params, returning=returning)
+        res = self._execute_sql(sql_string=result_sql, sql_params=sql_params, returning=returning)
+        self.commit()
+        return res
 
     def update(self, table, values, where=None, returning='*'):
         sql_params = {}
@@ -676,11 +670,7 @@ class TasksDatabase:
                     return None
             task_dict['params'] = params
         schema = TasksDatabase.pg_database.get_attr('schema')
-        res = TasksDatabase.pg_database.insert(table=f"{schema}.tasks", values=task_dict)
-        if not isinstance(res, psycopg2.extras.RealDictRow):
-            print(f'Error in {func_name}: isinstance(res, psycopg2.extras.RealDictRow)...')
-            return None
-        res_dict = dict(res)
+        res_dict = TasksDatabase.pg_database.insert(table=f"{schema}.tasks", values=task_dict)
         return res_dict.get('task_id')
 
     @classmethod
@@ -718,14 +708,8 @@ class TasksDatabase:
 
         task_dict = dict(tasks[0])
         update_values = {'started_time': datetime.datetime.now(), 'status': 'working'}
-        result = TasksDatabase.pg_database.update(table=f'{schema}.tasks', values=update_values,
-                                                  where={'task_id': task_dict.get('task_id')})
-        if not isinstance(result, psycopg2.extras.RealDictRow):
-            print(f'Error in {func_name}: isinstance(res, psycopg2.extras.RealDictRow)...')
-            TasksDatabase.pg_database.disconnect()
-            return None
-        task_dict = dict(result)
-
+        task_dict = TasksDatabase.pg_database.update(table=f'{schema}.tasks', values=update_values,
+                                                     where={'task_id': task_dict.get('task_id')})
         TasksDatabase.pg_database.commit()
         if disconnect:
             TasksDatabase.pg_database.disconnect()
@@ -823,9 +807,6 @@ class TasksDatabase:
         if schema is None:
             return False
         result = TasksDatabase.pg_database.update(table=f'{schema}.tasks', values=update_values, where={'task_id': task_id})
-        if not isinstance(result, psycopg2.extras.RealDictRow):
-            print(f'Error in {func_name}: isinstance(res, psycopg2.extras.RealDictRow)...')
-            return False
         return True
 
     @classmethod
