@@ -86,7 +86,7 @@ class Worker(object):
 
     def worker(self, task_dict):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
-        print(f'{func_name}; os.getpid(): {os.getpid()}; os.getppid(): {os.getppid()}')
+        # print(f'{func_name}; os.getpid(): {os.getpid()}; os.getppid(): {os.getppid()}')
         try:
             task_module = task_dict.get('module')
             task_func = task_dict.get('func')
@@ -99,9 +99,9 @@ class Worker(object):
                 params = task_dict.get('params')
                 if isinstance(params, str):
                     params = json.loads(params)
-                    if not isinstance(params, dict):
-                        params = dict()
-                    return func(**params)
+                if not isinstance(params, dict):
+                    params = dict()
+                return func(**params)
         except Exception as e:
             error = f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}'
             print(error)
@@ -144,7 +144,7 @@ class Worker(object):
 
     def _do_task(self, process_type):
         func_name = f'{self.__class__.__name__}.{sys._getframe().f_code.co_name}()'
-        print(f'{func_name}; os.getpid(): {os.getpid()}; os.getppid(): {os.getppid()}')
+        # print(f'{func_name}; os.getpid(): {os.getpid()}; os.getppid(): {os.getppid()}')
         if not self._started:
             print(f'{func_name}; self._started = False; return')
             return
@@ -192,7 +192,7 @@ class Worker(object):
                             database.update_task_error(task_dict, error)
 
             if not self._blocking:
-                threading.Timer(self._sleep_sec, self._do_task).start()
+                threading.Timer(self._sleep_sec, self._do_task, args=(process_type,)).start()
         except Exception as e:
             print(f'Error in {func_name}: {type(e)}: {str(e)}; traceback: {traceback.print_exc()}')
 
@@ -213,7 +213,7 @@ class Worker(object):
                 self._do_task(process_type)
                 time.sleep(self._sleep_sec)
         else:
-            self._do_task()
+            self._do_task(process_type)
 
     def stop(self):
         self._started = False
